/**
 * @module gArray
 * @type function tools
 * @description 针对数组的一些工具函数
 */
/**
 * @title forEachType
 * @description 从左/右（left/right）遍历数组 柯里化函数
 * @param type "left" | "right"
 * @param arr T[]
 * @param cb (value: T, index: number, array: T[]) => void
 * @returns array T[]
 * @example forEachType("right")([1,2,3],(v,k,arr)=>console.log(v,k,arr)]);
 */
declare const forEachType: (type?: "left" | "right") => <T>(arr: T[], cb: (value: T, index: number, array: T[]) => void) => void;
/**
 * @title forEach
 * @description 左遍历
 * @param arr T[]
 * @param cb (value: T, index: number, array: T[]) => void
 * @returns array T[]
 */
declare const forEach: <T>(arr: T[], cb: (value: T, index: number, array: T[]) => void) => void;
/**
 * @title forEachRight
 * @description 右遍历
 * @param arr T[]
 * @param cb (value: T, index: number, array: T[]) => void
 * @returns array T[]
 */
declare const forEachRight: <T>(arr: T[], cb: (value: T, index: number, array: T[]) => void) => void;
/**
 * @title isArrayLike
 * @description 判断是否类数组
 * @param val any
 * @returns boolean
 */
declare const isArrayLike: (val: any) => boolean;
/**
 * @title deepFlatten
 * @description 深度拉平数组
 * @param arr array
 * @returns array
 */
declare const deepFlatten: <T>(arr: T[]) => any;
/**
 * @title unique
 * @description 数组去重
 * @param arr array
 * @returns array
 */
declare const unique: <T>(arr: T[]) => T[];
/**
 * @title intersection
 * @description 获取数组交集
 * @param arrT []数组1
 * @param arrR []数组2
 * @returns []两数组同栈集合
 */
declare const intersection: <T extends any[], R extends any[]>(arrT: T, arrR: R) => any[];
/**
 * @title intersectionAll
 * @description 取多个数组的交集
 * @param ...arr [][]多个数组
 * @returns 数组交集
 */
declare const intersectionAll: (...args: any[]) => any;
/**
 * @title union
 * @description 多个元素的并集(去重)
 * @param ...arr [][]多个数组
 * @returns 数组并集
 */
declare const union: (...args: any[]) => unknown[];
/**
 * @title difference
 * @description 两个数组的差集
 * @param arrT []数组1
 * @param arrR []数组2
 * @returns 数组差集
 */
declare const difference: <T extends any[], R extends any[]>(arrT: T, arrR: R) => unknown[];
/**
 * @title differenceAll
 * @description 多个数组的差集
 * @param ...arr [][]多个数组
 * @returns 数组差集
 */
declare const differenceAll: (...args: any[]) => any;
/**
 * @title array2Tree
 * @description 将单层级数组转化为树形结构
 * @description parentId为父元素的唯一标识，id为元素的唯一标识，默认为'id', pid为元素的父元素标识，默认为'pid'，children为要生成多层级子元素的字段名，默认为'children'
 * @param arr 扁平数组
 * @param parentId
 * @param options <{ id = "id", pid = "pid", children = "children" }>
 * @returns 树形数组
 */
declare const array2Tree: <T>(arr: T[], parentId?: number, { id, pid, children }?: {
    id?: string | undefined;
    pid?: string | undefined;
    children?: string | undefined;
}) => T[];
/**
 * @title tree2Array
 * @description 树状结构转为一维数组
 * @description id为每个元素的唯一标识，默认为'id'，children为多层级的子元素列表字段，默认为'children'
 * @param arr 扁平数组
 * @param parentId
 * @param options <{ id = "id", children = "children" }>
 * @returns 一维数组
 */
declare const tree2Array: <T>(tree: T[], { id, children }?: {
    id?: string | undefined;
    children?: string | undefined;
}) => T[];
/**
 * @title array2Object
 * @description 数组转为对象
 * @description 如果数组元素为对象时指定对象的某个唯一字段为 key 值，没有指定则默认为下标索引值
 * @param arr 数组
 * @param key
 * @returns object
 */
declare const array2Object: (arr: any[], key: string | number) => any;
/**
 * @title getTreeChains
 * @description  根据标识获取树状结构的数据链
 * @param id  number|string
 * @param tree  <{children:[]}>[]
 * @param options  <{ id: "id", pId: "pId", children: "children" }>
 * @returns array
 */
declare const getTreeChains: <T>(id: any, tree: T[], filter?: string[], options?: {}) => T[];
/**
 * @title arrayLike2Array
 * @description 类数组转为数组
 * @param obj Iterable<T> | ArrayLike<T>
 * @returns T[]
 */
declare const arrayLike2Array: <T>(obj: Iterable<T> | ArrayLike<T>) => T[];
/**
 * @title chunk
 * @description 根据给定长度进行分组
 * @param arr T[]
 * @param size number
 * @returns T[][]
 */
declare const chunk: <T>(arr: T[], size: number) => T[][];
/**
 * @title compact
 * @description 过滤列表中的空数据
 * @param arr T[]
 * @returns T[]
 */
declare const compact: <T>(arr: T[]) => T[];
/**
 * @title countBy
 * @description 根据条件获取元素的出现次数
 * @param arr T[]
 * @returns T[]
 */
declare const countBy: <T>(arr: T[], fn?: (item: any) => any) => AnyObj<number>;
/**
 * @title countByValue
 * @description 获取指定元素的出现次数
 * @param arr
 * @param val
 * @returns number
 */
declare const countByValue: <T>(arr: T[], val: string | number) => number;
/**
 * @title indexOfAll
 * @description 获取指定元素的下标值
 * @param arr
 * @param val
 * @returns number[]
 */
declare const indexOfAll: <T>(arr: T[], val: T) => number[];
/**
 * @title shuffe
 * @description 随机排序
 * @param arr
 * @returns number[]
 */
declare const shuffe: <T>(arr: T[]) => T[];
/**
 * @title sample
 * @description 随机取数组中数据
 * @description size为取出元素的个数
 * @param arr any[]
 * @param size number
 * @returns any[]
 * @example sample([1, 2, 3, 4, 5, 6, 7, 8, 9], 3) 结果=>[4, 6, 8]
 */
declare const sample: (arr: any[], size?: number) => any[];
export { forEachType, forEach, forEachRight, isArrayLike, deepFlatten, unique, intersection, intersectionAll, union, difference, differenceAll, array2Tree, tree2Array, array2Object, getTreeChains, arrayLike2Array, chunk, compact, countBy, countByValue, indexOfAll, shuffe, sample, };
