/**
 * @module gObj
 * @type function tools
 * @description 针对对象的一些工具函数
 */
/**
 * @title keys
 * @description 获取keys 等同于Object.keys
 * @param data object
 * @returns (keyof data)[]
 */
declare const keys: <T>(data: T) => (keyof T)[];
/**
 * @title omitBy
 * @description 忽略某些属性
 * @param origin object 需要操作的对象
 * @param callback (origin[key])=>boolean 忽略的方法 类似数组filter 用法
 * @returns object
 */
declare const omitBy: <T>(origin: T, callback: Function) => {};
/**
 * @title pick
 * @description 挑选某些属性
 * @param origin 被操作对象
 * @param propList 需要挑选的字段数组
 * @returns object
 */
declare const pick: <T>(origin: T, propList: (keyof T)[]) => {};
/**
 * @title clone
 * @description 浅拷贝
 * @param origin 拷贝对象
 * @returns new origin
 */
declare const clone: <T extends Object>(origin: T, result?: {}) => T;
/**
 * @title deepClone
 * @description 深拷贝
 * @param data 拷贝对象 可以是正则/日期对象
 * @returns new origin
 */
declare const deepClone: <T>(data: any, weak?: WeakMap<object, any>) => T;
/**
 * @title extend
 * @description 合并对象 基于Object.assign
 * @param target 源对象
 * @param args 其余对象
 * @returns target
 */
declare const extend: (target: object, ...args: any[]) => any;
/**
 * @title filterKeys
 * @description 根据保留/删除(keep/remove)类型过滤字段 柯里化函数
 * @param type "keep"|"remove"
 * @param obj
 * @param keys  string[] 保留或者删除的数组
 * @returns object
 * @example filterKeys("keep")({a:1,b:2},['a']);
 */
declare const filterKeys: (type: "keep" | "remove") => (obj: AnyObj, keys?: string[]) => {};
/**
 * @title keepKeys
 * @description 保留给定字段 filterKeys("keep")
 * @param obj
 * @param keys  string[] 保留或者删除的数组
 * @returns object
 */
declare const keepKeys: (obj: AnyObj, keys?: string[]) => {};
/**
 * @title removeKeys
 * @description 删除给定字段 filterKeys("remove")
 * @param obj
 * @param keys  string[] 保留或者删除的数组
 * @returns object
 */
declare const removeKeys: (obj: AnyObj, keys?: string[]) => {};
/**
 * @title replaceKeys
 * @description 替换对象字段名
 * @param obj
 * @param rules {[key in obj]:newKey}
 * @returns object
 */
declare const replaceKeys: <T, R = any>(obj: T, rules: { [k in keyof T]: string; }) => R;
/**
 * @title mergeProperties
 * @description 覆盖对象属性 以初始化对象为基准 去除新对象多余字段，为缺失字段填充默认值，浅操作，仅对第一层字段有效
 * @param distObject 初始化对象
 * @param srcObject 传递过来新对象
 * @returns object
 */
declare function mergeProperties<T, R>(distObject: T, srcObject: R): T & {};
export { clone, deepClone, extend, filterKeys, keepKeys, removeKeys, replaceKeys, mergeProperties, keys, omitBy, pick, };
