"use strict";
/**
 * @module gType
 * @type function tools
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.isElement = exports.isNaN = exports.isUndefined = exports.isError = exports.isSymbol = exports.isSet = exports.isMap = exports.isRegExp = exports.isDate = exports.isPromise = exports.isFunction = exports.isBoolean = exports.isString = exports.isNumber = exports.isNull = exports.isArguments = exports.isArray = exports.isEmptyObject = exports.isEmpty = exports.isObject = exports.isType = void 0;
/**
 * @title isType
 * @description 判断类型的基础方法 柯里化函数
 * @param type string 类型字符串
 * @param val 判断的值
 * @returns boolean
 * @example isType('String')('测试用例');
 */
const isType = (type) => (val) => Object.prototype.toString.call(val) === `[object ${type}]`;
exports.isType = isType;
/**
 * @title isObject
 * @param val
 * @returns boolean
 */
const isObject = (val) => typeof val === "function" || (typeof val === "object" && !!val);
exports.isObject = isObject;
/**
 * @title isEmptyObject
 * @param val
 * @returns boolean
 */
const isEmptyObject = (val) => isObject(val) && JSON.stringify(val) == "{}";
exports.isEmptyObject = isEmptyObject;
/**
 * @title isArray
 * @param val
 * @returns boolean
 */
const isArray = (val) => Array.isArray(val);
exports.isArray = isArray;
/**
 * @title isArguments
 * @param val
 * @returns boolean
 */
const isArguments = isType("Arguments");
exports.isArguments = isArguments;
/**
 * @title isNull
 * @param val
 * @returns boolean
 */
const isNull = isType("Null");
exports.isNull = isNull;
/**
 * @title isNumber
 * @param val
 * @returns boolean
 */
const isNumber = isType("Number");
exports.isNumber = isNumber;
/**
 * @title isString
 * @param val
 * @returns boolean
 */
const isString = isType("String");
exports.isString = isString;
/**
 * @title isBoolean
 * @param val
 * @returns boolean
 */
const isBoolean = isType("Boolean");
exports.isBoolean = isBoolean;
/**
 * @title isFunction
 * @param val
 * @returns boolean
 */
const isFunction = isType("Function");
exports.isFunction = isFunction;
/**
 * @title isPromise
 * @param val
 * @returns boolean
 */
const isPromise = isType("Promise");
exports.isPromise = isPromise;
/**
 * @title isDate
 * @param val
 * @returns boolean
 */
const isDate = isType("Date");
exports.isDate = isDate;
/**
 * @title isRegExp
 * @param val
 * @returns boolean
 */
const isRegExp = isType("RegExp");
exports.isRegExp = isRegExp;
/**
 * @title isMap
 * @param val
 * @returns boolean
 */
const isMap = isType("Map");
exports.isMap = isMap;
/**
 * @title isSet
 * @param val
 * @returns boolean
 */
const isSet = isType("Set");
exports.isSet = isSet;
/**
 * @title isSymbol
 * @param val
 * @returns boolean
 */
const isSymbol = isType("Symbol");
exports.isSymbol = isSymbol;
/**
 * @title isError
 * @param val
 * @returns boolean
 */
const isError = isType("Error");
exports.isError = isError;
/**
 * @title isUndefined
 * @param val
 * @returns boolean
 */
const isUndefined = isType("Undefined");
exports.isUndefined = isUndefined;
/**
 * @title isEmpty
 * @param val
 * @returns boolean
 */
const isEmpty = (val) => isNull(val) || isUndefined(val);
exports.isEmpty = isEmpty;
/**
 * @title isNaN
 * @param val
 * @returns boolean
 */
const isNaN = (val) => Number.isNaN(val);
exports.isNaN = isNaN;
/**
 * @title isElement
 * @param val
 * @returns boolean
 */
const isElement = (val) => isObject(HTMLElement)
    ? val instanceof HTMLElement
    : isObject(val) && isString(val.nodeName) && val.nodeType === 1;
exports.isElement = isElement;
//# sourceMappingURL=gType.js.map